<?php

function brabus_add_google_fonts() {

  wp_enqueue_style( 'poppins-google-fonts', 'https://fonts.googleapis.com/css?family=Poppins:400,600,800', false );
  wp_enqueue_style( 'fjalla-google-fonts', 'https://fonts.googleapis.com/css?family=Fjalla+One', false );

}

add_action( 'wp_enqueue_scripts', 'brabus_add_google_fonts' );
if ( ! function_exists( 'brabus_enqueue_styles_and_scripts' ) ) {
	/**
	 * This function enqueues the required css and js files.
	 *
	 * @return void
	 */
	function brabus_enqueue_styles_and_scripts() {
		/**
		 * Enqueue css files.
		 */
		wp_enqueue_style( 'animate', get_template_directory_uri() . '/css/animate.min.css' );
		wp_enqueue_style( 'odometer', get_template_directory_uri() . '/css/odometer.min.css' );
		wp_enqueue_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css' );
		wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/css/fancybox.min.css' );
		wp_enqueue_style( 'bootsrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
		wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );
		wp_enqueue_style( 'brabus-main-style', get_template_directory_uri() . '/css/style.css' );
		wp_enqueue_style( 'brabus-stylesheet', get_stylesheet_uri() );
		wp_add_inline_style( 'brabus-stylesheet', brabus_dynamic_css() );

		/**
		 * Enqueue javascript files.
		 */

		wp_enqueue_script( 'comments', get_template_directory_uri() . '/js/comments.js', array(), false, false );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'swiper', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'tilt', get_template_directory_uri() . '/js/tilt.jquery.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'typewriter', get_template_directory_uri() . '/js/jquery.typewriter.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'odometer', get_template_directory_uri() . '/js/odometer.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'wow', get_template_directory_uri() . '/js/wow.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/js/fancybox.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'brabus-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false, true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		$data = array(
			'pre_loader_typewriter' => [],
			'audio_source' => '',
			'enable_sound_bar' => false
		);

		if( brabus_get_option( 'enable_preloader' ) ) {
			$typewriter_text = [];
			$text_rotater = brabus_get_option( 'pre_loader_text_rotater' );
			if( $text_rotater ) {
				foreach ( $text_rotater as $rotater ) {
					$typewriter_text[] = esc_html( $rotater['title'] );
				}
			}
			$data['pre_loader_typewriter'] = $typewriter_text;
		}
		if( brabus_get_option( 'enable_soundbar' ) ) {
			$data['audio_source'] = brabus_get_option( 'sound_bar_audio' ) ? esc_url( brabus_get_option( 'sound_bar_audio' ) ) : get_template_directory_uri() . '/audio/audio.mp3';
			$data['enable_sound_bar'] = true;
		}

		$comment_data = array(
			'name'      => esc_html__( 'Name is required', 'brabus' ),
			'email'     => esc_html__( 'Email is required', 'brabus' ),
			'comment'   => esc_html__( 'Comment is required', 'brabus' ),

		);

		wp_localize_script( 'brabus-scripts', 'data', $data );
		wp_localize_script( 'comments', 'comment_data', $comment_data );
	}

	add_action( 'wp_enqueue_scripts', 'brabus_enqueue_styles_and_scripts', 10 );
}

if( !function_exists( 'brabus_dynamic_css' ) ) {
	function brabus_dynamic_css() {

		$styles = '';
		if( brabus_get_option( 'logo_height' ) ) {
			$logo_height = str_replace(' ', '', brabus_get_option( 'logo_height' ) );
			$logo_height = str_replace('px', '', $logo_height);
			$styles .= "
				body .navbar > .logo img{
					height: {$logo_height}px;
				}
			";
		}
		if( brabus_get_option( 'enable_dynamic_color' ) ) {

			$site_color = ( brabus_get_option( 'theme_color' ) ) ? brabus_get_option( 'theme_color' ) : '#01f7b6';
			$body_bg_color = ( brabus_get_option( 'body_background_color' ) ) ? brabus_get_option( 'body_background_color' ) : '#fff';

			$styles .= "
				body{
					background: {$body_bg_color} !important;
				}
				
				.navigation-menu .inner .menu ul li ul li a:hover,
				.navigation-menu .inner blockquote,
				.page-header .container p,
				.text-box h3,
				.service-box small,
				.portfolio-box .content-box .inner h3 span,
				.news .post .post-content .inner .post-title a:hover,
				.footer.layout_two .footer-cta:hover,
				.footer .footer-quote h2,
				.footer .footer-quote .footer-cta:hover,
				.footer .footer-bottom h5,
				.services-content-block small,
				.works .project-box .content-box .inner h3 span,
				.works-single h3,
				.swiper-slider .swiper-slide .slide-inner .container h1
				
				{
					color: {$site_color} !important;
				}
				
				input[type='checkbox']:checked,
				input[type='submit'],
				button[type='submit'],
				preloader,
				.preloader .typewriter #typewriter-suffix ,
				.transition-overlay,
				.equalizer span,
				.navbar .hamburger span,
				.navbar .hamburger span:after,
				.navbar .left ul li ul,
				.navbar .site-menu ul li a:after,
				.navbar .site-menu ul li a:hover:before,
				.navbar .site-menu ul li ul,
				.swiper-slider .swiper-pagination-bullets .swiper-pagination-bullet:after,
				.process-box span,
				.service-box span,
				.news .post .post-content .inner blockquote,
				.blog-post .post-content .post-date,
				.blog-post .post-content blockquote,
				.side-content-post .post-content .post-date,
				.wpcf7 button[type='submit'],
				.blog-post .post-content .wp-block-quote,
				.blog-post .post-content blockquote,
				.sidebar .widget .widget-title:after,
				.sidebar .widget_tag_cloud .tagcloud a,
				.woocommerce ul.products li.product .onsale,
				.woocommerce span.onsale,
				.services-content-block span,
				.process span,
				.swiper-slider .swiper-slide .slide-inner .container .tagline span:after
				{
				  background-color: {$site_color} !important;
				}
				
				.navigation-menu .inner .menu ul li a:hover,
				.blog-post .post-content .post-link a,
				.blog-post .post-content .post-categories li a:hover,
				.side-content-post .post-content .post-link a,
				.footer .footer-quote .footer-cta:hover,
				.blog-post .post-content
				{
				  border-color: {$site_color}  !important;
				}
				
				.process span{border: 10px solid #f1f1f1;}
				
			";
		}

		return $styles;
	}
}

add_action( 'init', 'brabus_dynamic_css' );